<a name="{{ app|slugify }}-{{ version|slugify }}-{{ resource.name|slugify }}"><h2>{{ resource.name }}</h2></a><span class="tiny"><a href="#">Back to Top</a></span>
<h4>{{ resource_root }}/{{ app }}/{{ version }}/{{ resource.slug }}/</h4>
{% if resource.is_deprecated %}
<h4>DEPRECATED: {{ resource.is_deprecated }}</h4>
{% endif %}
{% if resource.get %}
<h3>GET</h3>
{% with resource.get as descriptor %}
{% include 'sharrock/descriptor_body.html' %}
{% endwith %}
{% endif %}
{% if resource.post %}
<h3>POST</h3>
{% with resource.post as descriptor %}
{% include 'sharrock/descriptor_body.html' %}
{% endwith %}
{% endif %}
{% if resource.put %}
<h3>PUT</h3>
{% with resource.put as descriptor %}
{% include 'sharrock/descriptor_body.html' %}
{% endwith %}
{% endif %}
{% if resource.delete %}
<h3>DELETE</h3>
{% with resource.delete as descriptor %}
{% include 'sharrock/descriptor_body.html' %}
{% endwith %}
{% endif %}